# coding: utf-8

"""
    gnomock

    `gnomock` is an HTTP wrapper for [Gnomock](https://github.com/orlangure/gnomock) integration and end-to-end testing toolkit. It allows to use Gnomock outside of Go ecosystem. Not all Gnomock features exist in this wrapper, but official presets, as well as basic general configuration, are supported.   # noqa: E501

    The version of the OpenAPI document: 1.4.7
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from gnomock.configuration import Configuration


class KafkaMessages(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'topic': 'str',
        'key': 'str',
        'value': 'str',
        'time': 'float'
    }

    attribute_map = {
        'topic': 'topic',
        'key': 'key',
        'value': 'value',
        'time': 'time'
    }

    def __init__(self, topic=None, key=None, value=None, time=None, local_vars_configuration=None):  # noqa: E501
        """KafkaMessages - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._topic = None
        self._key = None
        self._value = None
        self._time = None
        self.discriminator = None

        self.topic = topic
        self.key = key
        self.value = value
        if time is not None:
            self.time = time

    @property
    def topic(self):
        """Gets the topic of this KafkaMessages.  # noqa: E501


        :return: The topic of this KafkaMessages.  # noqa: E501
        :rtype: str
        """
        return self._topic

    @topic.setter
    def topic(self, topic):
        """Sets the topic of this KafkaMessages.


        :param topic: The topic of this KafkaMessages.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and topic is None:  # noqa: E501
            raise ValueError("Invalid value for `topic`, must not be `None`")  # noqa: E501

        self._topic = topic

    @property
    def key(self):
        """Gets the key of this KafkaMessages.  # noqa: E501


        :return: The key of this KafkaMessages.  # noqa: E501
        :rtype: str
        """
        return self._key

    @key.setter
    def key(self, key):
        """Sets the key of this KafkaMessages.


        :param key: The key of this KafkaMessages.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and key is None:  # noqa: E501
            raise ValueError("Invalid value for `key`, must not be `None`")  # noqa: E501

        self._key = key

    @property
    def value(self):
        """Gets the value of this KafkaMessages.  # noqa: E501


        :return: The value of this KafkaMessages.  # noqa: E501
        :rtype: str
        """
        return self._value

    @value.setter
    def value(self, value):
        """Sets the value of this KafkaMessages.


        :param value: The value of this KafkaMessages.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and value is None:  # noqa: E501
            raise ValueError("Invalid value for `value`, must not be `None`")  # noqa: E501

        self._value = value

    @property
    def time(self):
        """Gets the time of this KafkaMessages.  # noqa: E501

        timestamp in seconds  # noqa: E501

        :return: The time of this KafkaMessages.  # noqa: E501
        :rtype: float
        """
        return self._time

    @time.setter
    def time(self, time):
        """Sets the time of this KafkaMessages.

        timestamp in seconds  # noqa: E501

        :param time: The time of this KafkaMessages.  # noqa: E501
        :type: float
        """

        self._time = time

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, KafkaMessages):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, KafkaMessages):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    gnomock

    `gnomock` is an HTTP wrapper for [Gnomock](https://github.com/orlangure/gnomock) integration and end-to-end testing toolkit. It allows to use Gnomock outside of Go ecosystem. Not all Gnomock features exist in this wrapper, but official presets, as well as basic general configuration, are supported.   # noqa: E501

    The version of the OpenAPI document: 1.4.7
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from gnomock.configuration import Configuration


class SplunkRequest(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'preset': 'Splunk',
        'options': 'Options'
    }

    attribute_map = {
        'preset': 'preset',
        'options': 'options'
    }

    def __init__(self, preset=None, options=None, local_vars_configuration=None):  # noqa: E501
        """SplunkRequest - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._preset = None
        self._options = None
        self.discriminator = None

        if preset is not None:
            self.preset = preset
        if options is not None:
            self.options = options

    @property
    def preset(self):
        """Gets the preset of this SplunkRequest.  # noqa: E501


        :return: The preset of this SplunkRequest.  # noqa: E501
        :rtype: Splunk
        """
        return self._preset

    @preset.setter
    def preset(self, preset):
        """Sets the preset of this SplunkRequest.


        :param preset: The preset of this SplunkRequest.  # noqa: E501
        :type: Splunk
        """

        self._preset = preset

    @property
    def options(self):
        """Gets the options of this SplunkRequest.  # noqa: E501


        :return: The options of this SplunkRequest.  # noqa: E501
        :rtype: Options
        """
        return self._options

    @options.setter
    def options(self, options):
        """Sets the options of this SplunkRequest.


        :param options: The options of this SplunkRequest.  # noqa: E501
        :type: Options
        """

        self._options = options

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SplunkRequest):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, SplunkRequest):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    gnomock

    `gnomock` is an HTTP wrapper for [Gnomock](https://github.com/orlangure/gnomock) integration and end-to-end testing toolkit. It allows to use Gnomock outside of Go ecosystem. Not all Gnomock features exist in this wrapper, but official presets, as well as basic general configuration, are supported.   # noqa: E501

    The version of the OpenAPI document: 1.4.7
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from gnomock.api_client import ApiClient
from gnomock.exceptions import (  # noqa: F401
    ApiTypeError,
    ApiValueError
)


class PresetsApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def start_cockroach_db(self, cockroachdb_request, **kwargs):  # noqa: E501
        """Start a new Gnomock CockroachDB preset.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.start_cockroach_db(cockroachdb_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param CockroachdbRequest cockroachdb_request: (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Container
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.start_cockroach_db_with_http_info(cockroachdb_request, **kwargs)  # noqa: E501

    def start_cockroach_db_with_http_info(self, cockroachdb_request, **kwargs):  # noqa: E501
        """Start a new Gnomock CockroachDB preset.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.start_cockroach_db_with_http_info(cockroachdb_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param CockroachdbRequest cockroachdb_request: (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(Container, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'cockroachdb_request'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method start_cockroach_db" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'cockroachdb_request' is set
        if self.api_client.client_side_validation and ('cockroachdb_request' not in local_var_params or  # noqa: E501
                                                        local_var_params['cockroachdb_request'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `cockroachdb_request` when calling `start_cockroach_db`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'cockroachdb_request' in local_var_params:
            body_params = local_var_params['cockroachdb_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/start/cockroachdb', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Container',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def start_elastic(self, elastic_request, **kwargs):  # noqa: E501
        """Start a new Gnomock Elasticsearch container  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.start_elastic(elastic_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param ElasticRequest elastic_request: (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Container
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.start_elastic_with_http_info(elastic_request, **kwargs)  # noqa: E501

    def start_elastic_with_http_info(self, elastic_request, **kwargs):  # noqa: E501
        """Start a new Gnomock Elasticsearch container  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.start_elastic_with_http_info(elastic_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param ElasticRequest elastic_request: (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(Container, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'elastic_request'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method start_elastic" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'elastic_request' is set
        if self.api_client.client_side_validation and ('elastic_request' not in local_var_params or  # noqa: E501
                                                        local_var_params['elastic_request'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `elastic_request` when calling `start_elastic`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'elastic_request' in local_var_params:
            body_params = local_var_params['elastic_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/start/elastic', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Container',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def start_kafka(self, kafka_request, **kwargs):  # noqa: E501
        """Start a new Gnomock Kafka container  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.start_kafka(kafka_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param KafkaRequest kafka_request: (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Container
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.start_kafka_with_http_info(kafka_request, **kwargs)  # noqa: E501

    def start_kafka_with_http_info(self, kafka_request, **kwargs):  # noqa: E501
        """Start a new Gnomock Kafka container  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.start_kafka_with_http_info(kafka_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param KafkaRequest kafka_request: (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(Container, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'kafka_request'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method start_kafka" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'kafka_request' is set
        if self.api_client.client_side_validation and ('kafka_request' not in local_var_params or  # noqa: E501
                                                        local_var_params['kafka_request'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `kafka_request` when calling `start_kafka`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'kafka_request' in local_var_params:
            body_params = local_var_params['kafka_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/start/kafka', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Container',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def start_kubernetes(self, kubernetes_request, **kwargs):  # noqa: E501
        """Start a new Gnomock lightweight kubernetes (k3s) preset. Use `host:<kubeconfig-port>/kubeconfig` to retrieve the kubeconfig file that should be used to connect to this container.   # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.start_kubernetes(kubernetes_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param KubernetesRequest kubernetes_request: (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Container
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.start_kubernetes_with_http_info(kubernetes_request, **kwargs)  # noqa: E501

    def start_kubernetes_with_http_info(self, kubernetes_request, **kwargs):  # noqa: E501
        """Start a new Gnomock lightweight kubernetes (k3s) preset. Use `host:<kubeconfig-port>/kubeconfig` to retrieve the kubeconfig file that should be used to connect to this container.   # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.start_kubernetes_with_http_info(kubernetes_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param KubernetesRequest kubernetes_request: (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(Container, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'kubernetes_request'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method start_kubernetes" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'kubernetes_request' is set
        if self.api_client.client_side_validation and ('kubernetes_request' not in local_var_params or  # noqa: E501
                                                        local_var_params['kubernetes_request'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `kubernetes_request` when calling `start_kubernetes`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'kubernetes_request' in local_var_params:
            body_params = local_var_params['kubernetes_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/start/kubernetes', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Container',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def start_localstack(self, localstack_request, **kwargs):  # noqa: E501
        """Start a new Gnomock Localstack container  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.start_localstack(localstack_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param LocalstackRequest localstack_request: (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Container
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.start_localstack_with_http_info(localstack_request, **kwargs)  # noqa: E501

    def start_localstack_with_http_info(self, localstack_request, **kwargs):  # noqa: E501
        """Start a new Gnomock Localstack container  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.start_localstack_with_http_info(localstack_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param LocalstackRequest localstack_request: (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(Container, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'localstack_request'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method start_localstack" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'localstack_request' is set
        if self.api_client.client_side_validation and ('localstack_request' not in local_var_params or  # noqa: E501
                                                        local_var_params['localstack_request'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `localstack_request` when calling `start_localstack`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'localstack_request' in local_var_params:
            body_params = local_var_params['localstack_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/start/localstack', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Container',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def start_mariadb(self, mariadb_request, **kwargs):  # noqa: E501
        """Start a new Gnomock MariaDB container  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.start_mariadb(mariadb_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param MariadbRequest mariadb_request: (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Container
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.start_mariadb_with_http_info(mariadb_request, **kwargs)  # noqa: E501

    def start_mariadb_with_http_info(self, mariadb_request, **kwargs):  # noqa: E501
        """Start a new Gnomock MariaDB container  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.start_mariadb_with_http_info(mariadb_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param MariadbRequest mariadb_request: (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(Container, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'mariadb_request'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method start_mariadb" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'mariadb_request' is set
        if self.api_client.client_side_validation and ('mariadb_request' not in local_var_params or  # noqa: E501
                                                        local_var_params['mariadb_request'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `mariadb_request` when calling `start_mariadb`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'mariadb_request' in local_var_params:
            body_params = local_var_params['mariadb_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/start/mariadb', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Container',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def start_memcached(self, memcached_request, **kwargs):  # noqa: E501
        """Start a new Gnomock Memcached container  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.start_memcached(memcached_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param MemcachedRequest memcached_request: (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Container
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.start_memcached_with_http_info(memcached_request, **kwargs)  # noqa: E501

    def start_memcached_with_http_info(self, memcached_request, **kwargs):  # noqa: E501
        """Start a new Gnomock Memcached container  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.start_memcached_with_http_info(memcached_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param MemcachedRequest memcached_request: (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(Container, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'memcached_request'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method start_memcached" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'memcached_request' is set
        if self.api_client.client_side_validation and ('memcached_request' not in local_var_params or  # noqa: E501
                                                        local_var_params['memcached_request'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `memcached_request` when calling `start_memcached`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'memcached_request' in local_var_params:
            body_params = local_var_params['memcached_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/start/memcached', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Container',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def start_mongo(self, mongo_request, **kwargs):  # noqa: E501
        """Start a new Gnomock MongoDB container  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.start_mongo(mongo_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param MongoRequest mongo_request: (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Container
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.start_mongo_with_http_info(mongo_request, **kwargs)  # noqa: E501

    def start_mongo_with_http_info(self, mongo_request, **kwargs):  # noqa: E501
        """Start a new Gnomock MongoDB container  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.start_mongo_with_http_info(mongo_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param MongoRequest mongo_request: (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(Container, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'mongo_request'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method start_mongo" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'mongo_request' is set
        if self.api_client.client_side_validation and ('mongo_request' not in local_var_params or  # noqa: E501
                                                        local_var_params['mongo_request'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `mongo_request` when calling `start_mongo`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'mongo_request' in local_var_params:
            body_params = local_var_params['mongo_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/start/mongo', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Container',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def start_mssql(self, mssql_request, **kwargs):  # noqa: E501
        """Start a new Gnomock Microsoft SQL Server container  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.start_mssql(mssql_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param MssqlRequest mssql_request: (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Container
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.start_mssql_with_http_info(mssql_request, **kwargs)  # noqa: E501

    def start_mssql_with_http_info(self, mssql_request, **kwargs):  # noqa: E501
        """Start a new Gnomock Microsoft SQL Server container  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.start_mssql_with_http_info(mssql_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param MssqlRequest mssql_request: (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(Container, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'mssql_request'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method start_mssql" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'mssql_request' is set
        if self.api_client.client_side_validation and ('mssql_request' not in local_var_params or  # noqa: E501
                                                        local_var_params['mssql_request'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `mssql_request` when calling `start_mssql`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'mssql_request' in local_var_params:
            body_params = local_var_params['mssql_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/start/mssql', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Container',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def start_mysql(self, mysql_request, **kwargs):  # noqa: E501
        """Start a new Gnomock MySQL container  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.start_mysql(mysql_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param MysqlRequest mysql_request: (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Container
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.start_mysql_with_http_info(mysql_request, **kwargs)  # noqa: E501

    def start_mysql_with_http_info(self, mysql_request, **kwargs):  # noqa: E501
        """Start a new Gnomock MySQL container  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.start_mysql_with_http_info(mysql_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param MysqlRequest mysql_request: (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(Container, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'mysql_request'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method start_mysql" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'mysql_request' is set
        if self.api_client.client_side_validation and ('mysql_request' not in local_var_params or  # noqa: E501
                                                        local_var_params['mysql_request'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `mysql_request` when calling `start_mysql`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'mysql_request' in local_var_params:
            body_params = local_var_params['mysql_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/start/mysql', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Container',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def start_postgres(self, postgres_request, **kwargs):  # noqa: E501
        """Start a new Gnomock Postgres container  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.start_postgres(postgres_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param PostgresRequest postgres_request: (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Container
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.start_postgres_with_http_info(postgres_request, **kwargs)  # noqa: E501

    def start_postgres_with_http_info(self, postgres_request, **kwargs):  # noqa: E501
        """Start a new Gnomock Postgres container  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.start_postgres_with_http_info(postgres_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param PostgresRequest postgres_request: (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(Container, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'postgres_request'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method start_postgres" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'postgres_request' is set
        if self.api_client.client_side_validation and ('postgres_request' not in local_var_params or  # noqa: E501
                                                        local_var_params['postgres_request'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `postgres_request` when calling `start_postgres`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'postgres_request' in local_var_params:
            body_params = local_var_params['postgres_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/start/postgres', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Container',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def start_rabbit_mq(self, rabbitmq_request, **kwargs):  # noqa: E501
        """Start a new Gnomock RabbitMQ container  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.start_rabbit_mq(rabbitmq_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param RabbitmqRequest rabbitmq_request: (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Container
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.start_rabbit_mq_with_http_info(rabbitmq_request, **kwargs)  # noqa: E501

    def start_rabbit_mq_with_http_info(self, rabbitmq_request, **kwargs):  # noqa: E501
        """Start a new Gnomock RabbitMQ container  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.start_rabbit_mq_with_http_info(rabbitmq_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param RabbitmqRequest rabbitmq_request: (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(Container, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'rabbitmq_request'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method start_rabbit_mq" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'rabbitmq_request' is set
        if self.api_client.client_side_validation and ('rabbitmq_request' not in local_var_params or  # noqa: E501
                                                        local_var_params['rabbitmq_request'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `rabbitmq_request` when calling `start_rabbit_mq`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'rabbitmq_request' in local_var_params:
            body_params = local_var_params['rabbitmq_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/start/rabbitmq', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Container',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def start_redis(self, redis_request, **kwargs):  # noqa: E501
        """Start a new Gnomock Redis container  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.start_redis(redis_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param RedisRequest redis_request: (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Container
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.start_redis_with_http_info(redis_request, **kwargs)  # noqa: E501

    def start_redis_with_http_info(self, redis_request, **kwargs):  # noqa: E501
        """Start a new Gnomock Redis container  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.start_redis_with_http_info(redis_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param RedisRequest redis_request: (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(Container, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'redis_request'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method start_redis" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'redis_request' is set
        if self.api_client.client_side_validation and ('redis_request' not in local_var_params or  # noqa: E501
                                                        local_var_params['redis_request'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `redis_request` when calling `start_redis`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'redis_request' in local_var_params:
            body_params = local_var_params['redis_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/start/redis', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Container',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def start_splunk(self, splunk_request, **kwargs):  # noqa: E501
        """Start a new Gnomock Splunk container  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.start_splunk(splunk_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param SplunkRequest splunk_request: (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Container
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.start_splunk_with_http_info(splunk_request, **kwargs)  # noqa: E501

    def start_splunk_with_http_info(self, splunk_request, **kwargs):  # noqa: E501
        """Start a new Gnomock Splunk container  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.start_splunk_with_http_info(splunk_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param SplunkRequest splunk_request: (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(Container, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'splunk_request'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method start_splunk" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'splunk_request' is set
        if self.api_client.client_side_validation and ('splunk_request' not in local_var_params or  # noqa: E501
                                                        local_var_params['splunk_request'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `splunk_request` when calling `start_splunk`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'splunk_request' in local_var_params:
            body_params = local_var_params['splunk_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/start/splunk', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Container',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def stop(self, stop_request, **kwargs):  # noqa: E501
        """Stop an existing Gnomock container  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.stop(stop_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param StopRequest stop_request: (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.stop_with_http_info(stop_request, **kwargs)  # noqa: E501

    def stop_with_http_info(self, stop_request, **kwargs):  # noqa: E501
        """Stop an existing Gnomock container  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.stop_with_http_info(stop_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param StopRequest stop_request: (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'stop_request'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method stop" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'stop_request' is set
        if self.api_client.client_side_validation and ('stop_request' not in local_var_params or  # noqa: E501
                                                        local_var_params['stop_request'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `stop_request` when calling `stop`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'stop_request' in local_var_params:
            body_params = local_var_params['stop_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/stop', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    gnomock

    `gnomock` is an HTTP wrapper for [Gnomock](https://github.com/orlangure/gnomock) integration and end-to-end testing toolkit. It allows to use Gnomock outside of Go ecosystem. Not all Gnomock features exist in this wrapper, but official presets, as well as basic general configuration, are supported.   # noqa: E501

    The version of the OpenAPI document: 1.2.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import gnomock
from gnomock.api.presets_api import PresetsApi  # noqa: E501
from gnomock.rest import ApiException


class TestPresetsApi(unittest.TestCase):
    """PresetsApi unit test stubs"""

    def setUp(self):
        self.api = gnomock.api.presets_api.PresetsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_start_localstack(self):
        """Test case for start_localstack

        Start a new Gnomock Localstack container  # noqa: E501
        """
        pass

    def test_start_mongo(self):
        """Test case for start_mongo

        Start a new Gnomock MongoDB container  # noqa: E501
        """
        pass

    def test_start_mssql(self):
        """Test case for start_mssql

        Start a new Gnomock Microsoft SQL Server container  # noqa: E501
        """
        pass

    def test_start_mysql(self):
        """Test case for start_mysql

        Start a new Gnomock MySQL container  # noqa: E501
        """
        pass

    def test_start_postgres(self):
        """Test case for start_postgres

        Start a new Gnomock Postgres container  # noqa: E501
        """
        pass

    def test_start_redis(self):
        """Test case for start_redis

        Start a new Gnomock Redis container  # noqa: E501
        """
        pass

    def test_start_splunk(self):
        """Test case for start_splunk

        Start a new Gnomock Splunk container  # noqa: E501
        """
        pass

    def test_stop(self):
        """Test case for stop

        Stop an existing Gnomock container  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    gnomock

    `gnomock` is an HTTP wrapper for [Gnomock](https://github.com/orlangure/gnomock) integration and end-to-end testing toolkit. It allows to use Gnomock outside of Go ecosystem. Not all Gnomock features exist in this wrapper, but official presets, as well as basic general configuration, are supported.   # noqa: E501

    The version of the OpenAPI document: 1.4.7
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from gnomock.configuration import Configuration


class RabbitmqMessage(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'queue': 'str',
        'content_type': 'str',
        'string_body': 'str',
        'body': 'str'
    }

    attribute_map = {
        'queue': 'queue',
        'content_type': 'content_type',
        'string_body': 'string_body',
        'body': 'body'
    }

    def __init__(self, queue=None, content_type=None, string_body=None, body=None, local_vars_configuration=None):  # noqa: E501
        """RabbitmqMessage - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._queue = None
        self._content_type = None
        self._string_body = None
        self._body = None
        self.discriminator = None

        if queue is not None:
            self.queue = queue
        if content_type is not None:
            self.content_type = content_type
        if string_body is not None:
            self.string_body = string_body
        if body is not None:
            self.body = body

    @property
    def queue(self):
        """Gets the queue of this RabbitmqMessage.  # noqa: E501


        :return: The queue of this RabbitmqMessage.  # noqa: E501
        :rtype: str
        """
        return self._queue

    @queue.setter
    def queue(self, queue):
        """Sets the queue of this RabbitmqMessage.


        :param queue: The queue of this RabbitmqMessage.  # noqa: E501
        :type: str
        """

        self._queue = queue

    @property
    def content_type(self):
        """Gets the content_type of this RabbitmqMessage.  # noqa: E501


        :return: The content_type of this RabbitmqMessage.  # noqa: E501
        :rtype: str
        """
        return self._content_type

    @content_type.setter
    def content_type(self, content_type):
        """Sets the content_type of this RabbitmqMessage.


        :param content_type: The content_type of this RabbitmqMessage.  # noqa: E501
        :type: str
        """

        self._content_type = content_type

    @property
    def string_body(self):
        """Gets the string_body of this RabbitmqMessage.  # noqa: E501


        :return: The string_body of this RabbitmqMessage.  # noqa: E501
        :rtype: str
        """
        return self._string_body

    @string_body.setter
    def string_body(self, string_body):
        """Sets the string_body of this RabbitmqMessage.


        :param string_body: The string_body of this RabbitmqMessage.  # noqa: E501
        :type: str
        """

        self._string_body = string_body

    @property
    def body(self):
        """Gets the body of this RabbitmqMessage.  # noqa: E501


        :return: The body of this RabbitmqMessage.  # noqa: E501
        :rtype: str
        """
        return self._body

    @body.setter
    def body(self, body):
        """Sets the body of this RabbitmqMessage.


        :param body: The body of this RabbitmqMessage.  # noqa: E501
        :type: str
        """

        self._body = body

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RabbitmqMessage):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, RabbitmqMessage):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    gnomock

    `gnomock` is an HTTP wrapper for [Gnomock](https://github.com/orlangure/gnomock) integration and end-to-end testing toolkit. It allows to use Gnomock outside of Go ecosystem. Not all Gnomock features exist in this wrapper, but official presets, as well as basic general configuration, are supported.   # noqa: E501

    The version of the OpenAPI document: 1.4.7
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from gnomock.configuration import Configuration


class Options(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'timeout': 'int',
        'env': 'list[str]',
        'debug': 'bool',
        'container_name': 'str',
        'privileged': 'bool',
        'cmd': 'list[str]',
        'disable_cleanup': 'bool'
    }

    attribute_map = {
        'timeout': 'timeout',
        'env': 'env',
        'debug': 'debug',
        'container_name': 'container_name',
        'privileged': 'privileged',
        'cmd': 'cmd',
        'disable_cleanup': 'disable_cleanup'
    }

    def __init__(self, timeout=None, env=None, debug=False, container_name=None, privileged=None, cmd=None, disable_cleanup=None, local_vars_configuration=None):  # noqa: E501
        """Options - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._timeout = None
        self._env = None
        self._debug = None
        self._container_name = None
        self._privileged = None
        self._cmd = None
        self._disable_cleanup = None
        self.discriminator = None

        if timeout is not None:
            self.timeout = timeout
        if env is not None:
            self.env = env
        if debug is not None:
            self.debug = debug
        if container_name is not None:
            self.container_name = container_name
        if privileged is not None:
            self.privileged = privileged
        if cmd is not None:
            self.cmd = cmd
        if disable_cleanup is not None:
            self.disable_cleanup = disable_cleanup

    @property
    def timeout(self):
        """Gets the timeout of this Options.  # noqa: E501

        Wait timeout in nanoseconds  # noqa: E501

        :return: The timeout of this Options.  # noqa: E501
        :rtype: int
        """
        return self._timeout

    @timeout.setter
    def timeout(self, timeout):
        """Sets the timeout of this Options.

        Wait timeout in nanoseconds  # noqa: E501

        :param timeout: The timeout of this Options.  # noqa: E501
        :type: int
        """

        self._timeout = timeout

    @property
    def env(self):
        """Gets the env of this Options.  # noqa: E501

        Array of environment variables to set in the container  # noqa: E501

        :return: The env of this Options.  # noqa: E501
        :rtype: list[str]
        """
        return self._env

    @env.setter
    def env(self, env):
        """Sets the env of this Options.

        Array of environment variables to set in the container  # noqa: E501

        :param env: The env of this Options.  # noqa: E501
        :type: list[str]
        """

        self._env = env

    @property
    def debug(self):
        """Gets the debug of this Options.  # noqa: E501

        Set to true to see logs inside the Gnomock container  # noqa: E501

        :return: The debug of this Options.  # noqa: E501
        :rtype: bool
        """
        return self._debug

    @debug.setter
    def debug(self, debug):
        """Sets the debug of this Options.

        Set to true to see logs inside the Gnomock container  # noqa: E501

        :param debug: The debug of this Options.  # noqa: E501
        :type: bool
        """

        self._debug = debug

    @property
    def container_name(self):
        """Gets the container_name of this Options.  # noqa: E501

        Use a specific container name instead of a random one. In case a container with this name already exists, it is killed and replaced by a new container.   # noqa: E501

        :return: The container_name of this Options.  # noqa: E501
        :rtype: str
        """
        return self._container_name

    @container_name.setter
    def container_name(self, container_name):
        """Sets the container_name of this Options.

        Use a specific container name instead of a random one. In case a container with this name already exists, it is killed and replaced by a new container.   # noqa: E501

        :param container_name: The container_name of this Options.  # noqa: E501
        :type: str
        """

        self._container_name = container_name

    @property
    def privileged(self):
        """Gets the privileged of this Options.  # noqa: E501

        Runs a container in privileged mode.  # noqa: E501

        :return: The privileged of this Options.  # noqa: E501
        :rtype: bool
        """
        return self._privileged

    @privileged.setter
    def privileged(self, privileged):
        """Sets the privileged of this Options.

        Runs a container in privileged mode.  # noqa: E501

        :param privileged: The privileged of this Options.  # noqa: E501
        :type: bool
        """

        self._privileged = privileged

    @property
    def cmd(self):
        """Gets the cmd of this Options.  # noqa: E501

        Command and its arguments to execute on container startup.  # noqa: E501

        :return: The cmd of this Options.  # noqa: E501
        :rtype: list[str]
        """
        return self._cmd

    @cmd.setter
    def cmd(self, cmd):
        """Sets the cmd of this Options.

        Command and its arguments to execute on container startup.  # noqa: E501

        :param cmd: The cmd of this Options.  # noqa: E501
        :type: list[str]
        """

        self._cmd = cmd

    @property
    def disable_cleanup(self):
        """Gets the disable_cleanup of this Options.  # noqa: E501

        Disables auto removal of this container after tests.  # noqa: E501

        :return: The disable_cleanup of this Options.  # noqa: E501
        :rtype: bool
        """
        return self._disable_cleanup

    @disable_cleanup.setter
    def disable_cleanup(self, disable_cleanup):
        """Sets the disable_cleanup of this Options.

        Disables auto removal of this container after tests.  # noqa: E501

        :param disable_cleanup: The disable_cleanup of this Options.  # noqa: E501
        :type: bool
        """

        self._disable_cleanup = disable_cleanup

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Options):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Options):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    gnomock

    `gnomock` is an HTTP wrapper for [Gnomock](https://github.com/orlangure/gnomock) integration and end-to-end testing toolkit. It allows to use Gnomock outside of Go ecosystem. Not all Gnomock features exist in this wrapper, but official presets, as well as basic general configuration, are supported.   # noqa: E501

    The version of the OpenAPI document: 1.4.7
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from gnomock.configuration import Configuration


class Localstack(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'services': 'list[str]',
        's3_path': 'str',
        'version': 'str'
    }

    attribute_map = {
        'services': 'services',
        's3_path': 's3_path',
        'version': 'version'
    }

    def __init__(self, services=None, s3_path=None, version='latest', local_vars_configuration=None):  # noqa: E501
        """Localstack - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._services = None
        self._s3_path = None
        self._version = None
        self.discriminator = None

        self.services = services
        if s3_path is not None:
            self.s3_path = s3_path
        if version is not None:
            self.version = version

    @property
    def services(self):
        """Gets the services of this Localstack.  # noqa: E501

        A list of localstack services to start  # noqa: E501

        :return: The services of this Localstack.  # noqa: E501
        :rtype: list[str]
        """
        return self._services

    @services.setter
    def services(self, services):
        """Sets the services of this Localstack.

        A list of localstack services to start  # noqa: E501

        :param services: The services of this Localstack.  # noqa: E501
        :type: list[str]
        """
        if self.local_vars_configuration.client_side_validation and services is None:  # noqa: E501
            raise ValueError("Invalid value for `services`, must not be `None`")  # noqa: E501
        allowed_values = ["apigateway", "cloudformation", "cloudwatch", "logs", "events", "dynamodb", "dynamodbstreams", "ec2", "es", "firehose", "iam", "kinesis", "kms", "lambda", "redshift", "route53", "s3", "secretsmanager", "ses", "sns", "sqs", "ssm", "sts", "stepfunctions"]  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                not set(services).issubset(set(allowed_values))):  # noqa: E501
            raise ValueError(
                "Invalid values for `services` [{0}], must be a subset of [{1}]"  # noqa: E501
                .format(", ".join(map(str, set(services) - set(allowed_values))),  # noqa: E501
                        ", ".join(map(str, allowed_values)))
            )

        self._services = services

    @property
    def s3_path(self):
        """Gets the s3_path of this Localstack.  # noqa: E501

        Path to folder to setup initial S3 state. Top level folders are used as buckets; all child folders and files are uploaded as-is   # noqa: E501

        :return: The s3_path of this Localstack.  # noqa: E501
        :rtype: str
        """
        return self._s3_path

    @s3_path.setter
    def s3_path(self, s3_path):
        """Sets the s3_path of this Localstack.

        Path to folder to setup initial S3 state. Top level folders are used as buckets; all child folders and files are uploaded as-is   # noqa: E501

        :param s3_path: The s3_path of this Localstack.  # noqa: E501
        :type: str
        """

        self._s3_path = s3_path

    @property
    def version(self):
        """Gets the version of this Localstack.  # noqa: E501

        Docker image tag (version)  # noqa: E501

        :return: The version of this Localstack.  # noqa: E501
        :rtype: str
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this Localstack.

        Docker image tag (version)  # noqa: E501

        :param version: The version of this Localstack.  # noqa: E501
        :type: str
        """

        self._version = version

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Localstack):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Localstack):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    gnomock

    `gnomock` is an HTTP wrapper for [Gnomock](https://github.com/orlangure/gnomock) integration and end-to-end testing toolkit. It allows to use Gnomock outside of Go ecosystem. Not all Gnomock features exist in this wrapper, but official presets, as well as basic general configuration, are supported.   # noqa: E501

    The version of the OpenAPI document: 1.4.7
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from gnomock.configuration import Configuration


class Kafka(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'messages': 'list[KafkaMessages]',
        'messages_files': 'list[str]',
        'topics': 'list[str]',
        'version': 'str'
    }

    attribute_map = {
        'messages': 'messages',
        'messages_files': 'messages_files',
        'topics': 'topics',
        'version': 'version'
    }

    def __init__(self, messages=None, messages_files=None, topics=None, version='2.5.1-L0', local_vars_configuration=None):  # noqa: E501
        """Kafka - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._messages = None
        self._messages_files = None
        self._topics = None
        self._version = None
        self.discriminator = None

        if messages is not None:
            self.messages = messages
        if messages_files is not None:
            self.messages_files = messages_files
        if topics is not None:
            self.topics = topics
        if version is not None:
            self.version = version

    @property
    def messages(self):
        """Gets the messages of this Kafka.  # noqa: E501

        A list of messages to send to Kafka.  # noqa: E501

        :return: The messages of this Kafka.  # noqa: E501
        :rtype: list[KafkaMessages]
        """
        return self._messages

    @messages.setter
    def messages(self, messages):
        """Sets the messages of this Kafka.

        A list of messages to send to Kafka.  # noqa: E501

        :param messages: The messages of this Kafka.  # noqa: E501
        :type: list[KafkaMessages]
        """

        self._messages = messages

    @property
    def messages_files(self):
        """Gets the messages_files of this Kafka.  # noqa: E501


        :return: The messages_files of this Kafka.  # noqa: E501
        :rtype: list[str]
        """
        return self._messages_files

    @messages_files.setter
    def messages_files(self, messages_files):
        """Sets the messages_files of this Kafka.


        :param messages_files: The messages_files of this Kafka.  # noqa: E501
        :type: list[str]
        """

        self._messages_files = messages_files

    @property
    def topics(self):
        """Gets the topics of this Kafka.  # noqa: E501

        Topic names to create in Kafka.  # noqa: E501

        :return: The topics of this Kafka.  # noqa: E501
        :rtype: list[str]
        """
        return self._topics

    @topics.setter
    def topics(self, topics):
        """Sets the topics of this Kafka.

        Topic names to create in Kafka.  # noqa: E501

        :param topics: The topics of this Kafka.  # noqa: E501
        :type: list[str]
        """

        self._topics = topics

    @property
    def version(self):
        """Gets the version of this Kafka.  # noqa: E501

        Kafka version.  # noqa: E501

        :return: The version of this Kafka.  # noqa: E501
        :rtype: str
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this Kafka.

        Kafka version.  # noqa: E501

        :param version: The version of this Kafka.  # noqa: E501
        :type: str
        """

        self._version = version

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Kafka):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Kafka):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    gnomock

    `gnomock` is an HTTP wrapper for [Gnomock](https://github.com/orlangure/gnomock) integration and end-to-end testing toolkit. It allows to use Gnomock outside of Go ecosystem. Not all Gnomock features exist in this wrapper, but official presets, as well as basic general configuration, are supported.   # noqa: E501

    The version of the OpenAPI document: 1.4.7
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from gnomock.configuration import Configuration


class Mongo(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'data_path': 'str',
        'user': 'str',
        'password': 'str',
        'version': 'str'
    }

    attribute_map = {
        'data_path': 'data_path',
        'user': 'user',
        'password': 'password',
        'version': 'version'
    }

    def __init__(self, data_path=None, user=None, password=None, version='latest', local_vars_configuration=None):  # noqa: E501
        """Mongo - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._data_path = None
        self._user = None
        self._password = None
        self._version = None
        self.discriminator = None

        if data_path is not None:
            self.data_path = data_path
        if user is not None:
            self.user = user
        if password is not None:
            self.password = password
        if version is not None:
            self.version = version

    @property
    def data_path(self):
        """Gets the data_path of this Mongo.  # noqa: E501

        Path to folder to setup initial container state. Each top level folder maps to a database, every separate file under it is a collection, and every line is a document in that collection.   # noqa: E501

        :return: The data_path of this Mongo.  # noqa: E501
        :rtype: str
        """
        return self._data_path

    @data_path.setter
    def data_path(self, data_path):
        """Sets the data_path of this Mongo.

        Path to folder to setup initial container state. Each top level folder maps to a database, every separate file under it is a collection, and every line is a document in that collection.   # noqa: E501

        :param data_path: The data_path of this Mongo.  # noqa: E501
        :type: str
        """

        self._data_path = data_path

    @property
    def user(self):
        """Gets the user of this Mongo.  # noqa: E501

        Username to create inside the container.  # noqa: E501

        :return: The user of this Mongo.  # noqa: E501
        :rtype: str
        """
        return self._user

    @user.setter
    def user(self, user):
        """Sets the user of this Mongo.

        Username to create inside the container.  # noqa: E501

        :param user: The user of this Mongo.  # noqa: E501
        :type: str
        """

        self._user = user

    @property
    def password(self):
        """Gets the password of this Mongo.  # noqa: E501

        Password to set for the created user.  # noqa: E501

        :return: The password of this Mongo.  # noqa: E501
        :rtype: str
        """
        return self._password

    @password.setter
    def password(self, password):
        """Sets the password of this Mongo.

        Password to set for the created user.  # noqa: E501

        :param password: The password of this Mongo.  # noqa: E501
        :type: str
        """

        self._password = password

    @property
    def version(self):
        """Gets the version of this Mongo.  # noqa: E501

        Docker image tag (version)  # noqa: E501

        :return: The version of this Mongo.  # noqa: E501
        :rtype: str
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this Mongo.

        Docker image tag (version)  # noqa: E501

        :param version: The version of this Mongo.  # noqa: E501
        :type: str
        """

        self._version = version

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Mongo):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Mongo):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    gnomock

    `gnomock` is an HTTP wrapper for [Gnomock](https://github.com/orlangure/gnomock) integration and end-to-end testing toolkit. It allows to use Gnomock outside of Go ecosystem. Not all Gnomock features exist in this wrapper, but official presets, as well as basic general configuration, are supported.   # noqa: E501

    The version of the OpenAPI document: 1.4.7
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from gnomock.configuration import Configuration


class Splunk(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'values': 'list[SplunkValues]',
        'values_file': 'str',
        'accept_license': 'bool',
        'admin_password': 'str',
        'version': 'str'
    }

    attribute_map = {
        'values': 'values',
        'values_file': 'values_file',
        'accept_license': 'accept_license',
        'admin_password': 'admin_password',
        'version': 'version'
    }

    def __init__(self, values=None, values_file=None, accept_license=None, admin_password=None, version='latest', local_vars_configuration=None):  # noqa: E501
        """Splunk - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._values = None
        self._values_file = None
        self._accept_license = None
        self._admin_password = None
        self._version = None
        self.discriminator = None

        if values is not None:
            self.values = values
        if values_file is not None:
            self.values_file = values_file
        self.accept_license = accept_license
        self.admin_password = admin_password
        if version is not None:
            self.version = version

    @property
    def values(self):
        """Gets the values of this Splunk.  # noqa: E501

        A list of events to ingest into the container.  # noqa: E501

        :return: The values of this Splunk.  # noqa: E501
        :rtype: list[SplunkValues]
        """
        return self._values

    @values.setter
    def values(self, values):
        """Sets the values of this Splunk.

        A list of events to ingest into the container.  # noqa: E501

        :param values: The values of this Splunk.  # noqa: E501
        :type: list[SplunkValues]
        """

        self._values = values

    @property
    def values_file(self):
        """Gets the values_file of this Splunk.  # noqa: E501

        File name with events to ingest into Splunk. Use JSON Lines format (every event is a separate JSON object), each new event starts from a new line.   # noqa: E501

        :return: The values_file of this Splunk.  # noqa: E501
        :rtype: str
        """
        return self._values_file

    @values_file.setter
    def values_file(self, values_file):
        """Sets the values_file of this Splunk.

        File name with events to ingest into Splunk. Use JSON Lines format (every event is a separate JSON object), each new event starts from a new line.   # noqa: E501

        :param values_file: The values_file of this Splunk.  # noqa: E501
        :type: str
        """

        self._values_file = values_file

    @property
    def accept_license(self):
        """Gets the accept_license of this Splunk.  # noqa: E501

        Accept or decline Splunk license.  # noqa: E501

        :return: The accept_license of this Splunk.  # noqa: E501
        :rtype: bool
        """
        return self._accept_license

    @accept_license.setter
    def accept_license(self, accept_license):
        """Sets the accept_license of this Splunk.

        Accept or decline Splunk license.  # noqa: E501

        :param accept_license: The accept_license of this Splunk.  # noqa: E501
        :type: bool
        """
        if self.local_vars_configuration.client_side_validation and accept_license is None:  # noqa: E501
            raise ValueError("Invalid value for `accept_license`, must not be `None`")  # noqa: E501

        self._accept_license = accept_license

    @property
    def admin_password(self):
        """Gets the admin_password of this Splunk.  # noqa: E501

        Set a password for `admin` user.  # noqa: E501

        :return: The admin_password of this Splunk.  # noqa: E501
        :rtype: str
        """
        return self._admin_password

    @admin_password.setter
    def admin_password(self, admin_password):
        """Sets the admin_password of this Splunk.

        Set a password for `admin` user.  # noqa: E501

        :param admin_password: The admin_password of this Splunk.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and admin_password is None:  # noqa: E501
            raise ValueError("Invalid value for `admin_password`, must not be `None`")  # noqa: E501

        self._admin_password = admin_password

    @property
    def version(self):
        """Gets the version of this Splunk.  # noqa: E501

        Splunk version.  # noqa: E501

        :return: The version of this Splunk.  # noqa: E501
        :rtype: str
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this Splunk.

        Splunk version.  # noqa: E501

        :param version: The version of this Splunk.  # noqa: E501
        :type: str
        """

        self._version = version

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Splunk):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Splunk):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    gnomock

    `gnomock` is an HTTP wrapper for [Gnomock](https://github.com/orlangure/gnomock) integration and end-to-end testing toolkit. It allows to use Gnomock outside of Go ecosystem. Not all Gnomock features exist in this wrapper, but official presets, as well as basic general configuration, are supported.   # noqa: E501

    The version of the OpenAPI document: 1.4.7
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from gnomock.configuration import Configuration


class Mysql(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'db': 'str',
        'user': 'str',
        'password': 'str',
        'queries': 'list[str]',
        'queries_files': 'list[str]',
        'version': 'str'
    }

    attribute_map = {
        'db': 'db',
        'user': 'user',
        'password': 'password',
        'queries': 'queries',
        'queries_files': 'queries_files',
        'version': 'version'
    }

    def __init__(self, db='mydb', user='gnomock', password='gnomick', queries=None, queries_files=None, version='latest', local_vars_configuration=None):  # noqa: E501
        """Mysql - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._db = None
        self._user = None
        self._password = None
        self._queries = None
        self._queries_files = None
        self._version = None
        self.discriminator = None

        if db is not None:
            self.db = db
        if user is not None:
            self.user = user
        if password is not None:
            self.password = password
        if queries is not None:
            self.queries = queries
        if queries_files is not None:
            self.queries_files = queries_files
        if version is not None:
            self.version = version

    @property
    def db(self):
        """Gets the db of this Mysql.  # noqa: E501

        Database name to create.  # noqa: E501

        :return: The db of this Mysql.  # noqa: E501
        :rtype: str
        """
        return self._db

    @db.setter
    def db(self, db):
        """Sets the db of this Mysql.

        Database name to create.  # noqa: E501

        :param db: The db of this Mysql.  # noqa: E501
        :type: str
        """

        self._db = db

    @property
    def user(self):
        """Gets the user of this Mysql.  # noqa: E501

        User to create in the container.  # noqa: E501

        :return: The user of this Mysql.  # noqa: E501
        :rtype: str
        """
        return self._user

    @user.setter
    def user(self, user):
        """Sets the user of this Mysql.

        User to create in the container.  # noqa: E501

        :param user: The user of this Mysql.  # noqa: E501
        :type: str
        """

        self._user = user

    @property
    def password(self):
        """Gets the password of this Mysql.  # noqa: E501

        New user's password.  # noqa: E501

        :return: The password of this Mysql.  # noqa: E501
        :rtype: str
        """
        return self._password

    @password.setter
    def password(self, password):
        """Sets the password of this Mysql.

        New user's password.  # noqa: E501

        :param password: The password of this Mysql.  # noqa: E501
        :type: str
        """

        self._password = password

    @property
    def queries(self):
        """Gets the queries of this Mysql.  # noqa: E501

        A list of queries to execute while setting up the container.   # noqa: E501

        :return: The queries of this Mysql.  # noqa: E501
        :rtype: list[str]
        """
        return self._queries

    @queries.setter
    def queries(self, queries):
        """Sets the queries of this Mysql.

        A list of queries to execute while setting up the container.   # noqa: E501

        :param queries: The queries of this Mysql.  # noqa: E501
        :type: list[str]
        """

        self._queries = queries

    @property
    def queries_files(self):
        """Gets the queries_files of this Mysql.  # noqa: E501

        SQL files to execute while setting up container state.  # noqa: E501

        :return: The queries_files of this Mysql.  # noqa: E501
        :rtype: list[str]
        """
        return self._queries_files

    @queries_files.setter
    def queries_files(self, queries_files):
        """Sets the queries_files of this Mysql.

        SQL files to execute while setting up container state.  # noqa: E501

        :param queries_files: The queries_files of this Mysql.  # noqa: E501
        :type: list[str]
        """

        self._queries_files = queries_files

    @property
    def version(self):
        """Gets the version of this Mysql.  # noqa: E501

        Docker image tag (version)  # noqa: E501

        :return: The version of this Mysql.  # noqa: E501
        :rtype: str
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this Mysql.

        Docker image tag (version)  # noqa: E501

        :param version: The version of this Mysql.  # noqa: E501
        :type: str
        """

        self._version = version

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Mysql):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Mysql):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

# flake8: noqa

"""
    gnomock

    `gnomock` is an HTTP wrapper for [Gnomock](https://github.com/orlangure/gnomock) integration and end-to-end testing toolkit. It allows to use Gnomock outside of Go ecosystem. Not all Gnomock features exist in this wrapper, but official presets, as well as basic general configuration, are supported.   # noqa: E501

    The version of the OpenAPI document: 1.4.7
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

__version__ = "1.4.7"

# import apis into sdk package
from gnomock.api.presets_api import PresetsApi

# import ApiClient
from gnomock.api_client import ApiClient
from gnomock.configuration import Configuration
from gnomock.exceptions import OpenApiException
from gnomock.exceptions import ApiTypeError
from gnomock.exceptions import ApiValueError
from gnomock.exceptions import ApiKeyError
from gnomock.exceptions import ApiException
# import models into sdk package
from gnomock.models.cockroachdb import Cockroachdb
from gnomock.models.cockroachdb_request import CockroachdbRequest
from gnomock.models.container import Container
from gnomock.models.elastic import Elastic
from gnomock.models.elastic_request import ElasticRequest
from gnomock.models.invalid_start_request import InvalidStartRequest
from gnomock.models.invalid_stop_request import InvalidStopRequest
from gnomock.models.kafka import Kafka
from gnomock.models.kafka_messages import KafkaMessages
from gnomock.models.kafka_request import KafkaRequest
from gnomock.models.kubernetes import Kubernetes
from gnomock.models.kubernetes_request import KubernetesRequest
from gnomock.models.localstack import Localstack
from gnomock.models.localstack_request import LocalstackRequest
from gnomock.models.mariadb import Mariadb
from gnomock.models.mariadb_request import MariadbRequest
from gnomock.models.memcached import Memcached
from gnomock.models.memcached_request import MemcachedRequest
from gnomock.models.mongo import Mongo
from gnomock.models.mongo_request import MongoRequest
from gnomock.models.mssql import Mssql
from gnomock.models.mssql_request import MssqlRequest
from gnomock.models.mysql import Mysql
from gnomock.models.mysql_request import MysqlRequest
from gnomock.models.options import Options
from gnomock.models.postgres import Postgres
from gnomock.models.postgres_request import PostgresRequest
from gnomock.models.rabbitmq import Rabbitmq
from gnomock.models.rabbitmq_message import RabbitmqMessage
from gnomock.models.rabbitmq_request import RabbitmqRequest
from gnomock.models.redis import Redis
from gnomock.models.redis_request import RedisRequest
from gnomock.models.splunk import Splunk
from gnomock.models.splunk_request import SplunkRequest
from gnomock.models.splunk_values import SplunkValues
from gnomock.models.start_failed import StartFailed
from gnomock.models.stop_failed import StopFailed
from gnomock.models.stop_request import StopRequest




# coding: utf-8

"""
    gnomock

    `gnomock` is an HTTP wrapper for [Gnomock](https://github.com/orlangure/gnomock) integration and end-to-end testing toolkit. It allows to use Gnomock outside of Go ecosystem. Not all Gnomock features exist in this wrapper, but official presets, as well as basic general configuration, are supported.   # noqa: E501

    The version of the OpenAPI document: 1.4.7
    Generated by: https://openapi-generator.tech
"""


from setuptools import setup, find_packages  # noqa: H301

NAME = "gnomock-python-sdk"
VERSION = "1.4.7"
# To install the library, run the following
#
# python setup.py install
#
# prerequisite: setuptools
# http://pypi.python.org/pypi/setuptools

REQUIRES = ["urllib3 >= 1.15", "six >= 1.10", "certifi", "python-dateutil"]

setup(
    name=NAME,
    version=VERSION,
    description="gnomock",
    author="OpenAPI Generator community",
    author_email="team@openapitools.org",
    url="",
    keywords=["OpenAPI", "OpenAPI-Generator", "gnomock"],
    install_requires=REQUIRES,
    packages=find_packages(exclude=["test", "tests"]),
    include_package_data=True,
    license="MIT",
    long_description="""\
    &#x60;gnomock&#x60; is an HTTP wrapper for [Gnomock](https://github.com/orlangure/gnomock) integration and end-to-end testing toolkit. It allows to use Gnomock outside of Go ecosystem. Not all Gnomock features exist in this wrapper, but official presets, as well as basic general configuration, are supported.   # noqa: E501
    """
)



# coding: utf-8

"""
    gnomock

    `gnomock` is an HTTP wrapper for [Gnomock](https://github.com/orlangure/gnomock) integration and end-to-end testing toolkit. It allows to use Gnomock outside of Go ecosystem. Not all Gnomock features exist in this wrapper, but official presets, as well as basic general configuration, are supported.   # noqa: E501

    The version of the OpenAPI document: 1.4.2
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import gnomock
from gnomock.models.memcached_request import MemcachedRequest  # noqa: E501
from gnomock.rest import ApiException

class TestMemcachedRequest(unittest.TestCase):
    """MemcachedRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test MemcachedRequest
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = gnomock.models.memcached_request.MemcachedRequest()  # noqa: E501
        if include_optional :
            return MemcachedRequest(
                preset = gnomock.models.memcached.Memcached(
                    values = {"computer":"hal9000"}, 
                    byte_values = {"foo":"YmFy","baz":"NDI=","meh":"My4xNA=="}, 
                    version = 'latest', ), 
                options = gnomock.models.options.Options(
                    timeout = 60000000000, 
                    env = [
                        'ENV_VAR_NAME=some-value'
                        ], 
                    debug = True, 
                    container_name = 'gnomock', )
            )
        else :
            return MemcachedRequest(
        )

    def testMemcachedRequest(self):
        """Test MemcachedRequest"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    gnomock

    `gnomock` is an HTTP wrapper for [Gnomock](https://github.com/orlangure/gnomock) integration and end-to-end testing toolkit. It allows to use Gnomock outside of Go ecosystem. Not all Gnomock features exist in this wrapper, but official presets, as well as basic general configuration, are supported.   # noqa: E501

    The version of the OpenAPI document: 1.4.7
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from gnomock.configuration import Configuration


class SplunkValues(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'event': 'str',
        'index': 'str',
        'source': 'str',
        'sourcetype': 'str',
        'time': 'float'
    }

    attribute_map = {
        'event': 'event',
        'index': 'index',
        'source': 'source',
        'sourcetype': 'sourcetype',
        'time': 'time'
    }

    def __init__(self, event=None, index=None, source=None, sourcetype=None, time=None, local_vars_configuration=None):  # noqa: E501
        """SplunkValues - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._event = None
        self._index = None
        self._source = None
        self._sourcetype = None
        self._time = None
        self.discriminator = None

        self.event = event
        self.index = index
        self.source = source
        self.sourcetype = sourcetype
        self.time = time

    @property
    def event(self):
        """Gets the event of this SplunkValues.  # noqa: E501


        :return: The event of this SplunkValues.  # noqa: E501
        :rtype: str
        """
        return self._event

    @event.setter
    def event(self, event):
        """Sets the event of this SplunkValues.


        :param event: The event of this SplunkValues.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and event is None:  # noqa: E501
            raise ValueError("Invalid value for `event`, must not be `None`")  # noqa: E501

        self._event = event

    @property
    def index(self):
        """Gets the index of this SplunkValues.  # noqa: E501


        :return: The index of this SplunkValues.  # noqa: E501
        :rtype: str
        """
        return self._index

    @index.setter
    def index(self, index):
        """Sets the index of this SplunkValues.


        :param index: The index of this SplunkValues.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and index is None:  # noqa: E501
            raise ValueError("Invalid value for `index`, must not be `None`")  # noqa: E501

        self._index = index

    @property
    def source(self):
        """Gets the source of this SplunkValues.  # noqa: E501


        :return: The source of this SplunkValues.  # noqa: E501
        :rtype: str
        """
        return self._source

    @source.setter
    def source(self, source):
        """Sets the source of this SplunkValues.


        :param source: The source of this SplunkValues.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and source is None:  # noqa: E501
            raise ValueError("Invalid value for `source`, must not be `None`")  # noqa: E501

        self._source = source

    @property
    def sourcetype(self):
        """Gets the sourcetype of this SplunkValues.  # noqa: E501


        :return: The sourcetype of this SplunkValues.  # noqa: E501
        :rtype: str
        """
        return self._sourcetype

    @sourcetype.setter
    def sourcetype(self, sourcetype):
        """Sets the sourcetype of this SplunkValues.


        :param sourcetype: The sourcetype of this SplunkValues.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and sourcetype is None:  # noqa: E501
            raise ValueError("Invalid value for `sourcetype`, must not be `None`")  # noqa: E501

        self._sourcetype = sourcetype

    @property
    def time(self):
        """Gets the time of this SplunkValues.  # noqa: E501

        timestamp in seconds (or milli-, micro- or nanoseconds)  # noqa: E501

        :return: The time of this SplunkValues.  # noqa: E501
        :rtype: float
        """
        return self._time

    @time.setter
    def time(self, time):
        """Sets the time of this SplunkValues.

        timestamp in seconds (or milli-, micro- or nanoseconds)  # noqa: E501

        :param time: The time of this SplunkValues.  # noqa: E501
        :type: float
        """
        if self.local_vars_configuration.client_side_validation and time is None:  # noqa: E501
            raise ValueError("Invalid value for `time`, must not be `None`")  # noqa: E501

        self._time = time

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SplunkValues):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, SplunkValues):
            return True

        return self.to_dict() != other.to_dict()
